#include "HandleWebServer.h"
#include "hardware.h"
#include "AsyncJson.h"
#include "ArduinoJson.h"

extern AsyncWebServer myServer;

void configServer(void) {
  myServer.on("/", HTTP_GET, [](AsyncWebServerRequest * request)
  {
    request->send(SPIFFS, "/telecommande.html");
  });

  myServer.on("/telecommande.png", HTTP_GET, [](AsyncWebServerRequest * request)
  {
    request->send(SPIFFS, "/telecommande.png", "image/png");
  });

  myServer.on("/telecommande.js", HTTP_GET, [](AsyncWebServerRequest * request)
  {
    request->send(SPIFFS, "/telecommande.js", "application/javascript");
  });

  myServer.on("/telecommande.css", HTTP_GET, [](AsyncWebServerRequest * request)
  {
    request->send(SPIFFS, "/telecommande.css", "text/css");
  });

  myServer.on("/ajax", HTTP_GET, [](AsyncWebServerRequest * request)
  {
    if (request->hasParam("led")) {
      AsyncWebParameter* p = request->getParam("led");
      String val = p->value();
      if (val == "ON") {
        Serial.println("Allumer ON");
        setLedState(HIGH);
      }
      else if (val == "OFF") {
        Serial.println("Eteindre OFF");
        setLedState(LOW);
      }
      sendJsonResponse(request);
    }
    else if (request->hasParam("maj")) {
      Serial.println("MAJ");
      sendJsonResponse(request);
    }
  });

  myServer.onNotFound([](AsyncWebServerRequest * request) {
    request->send(404, "text/plain", "Erreur 404");
  });
}

void sendJsonResponse(AsyncWebServerRequest *request) {
  AsyncResponseStream *response = request->beginResponseStream("application/json");
  DynamicJsonDocument doc(1024);
  doc["bouton"] = getLedState() == HIGH ? "ledOn" : "ledOff";
  doc["temperature"] = getTemperature();
  serializeJson(doc, *response);
  request->send(response);
}
